bpca <-
  function(x, ...) UseMethod('bpca', x)
